{% load i18n %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>{% trans 'Server error (500)' %}</title>
    <style>
        @import url(/static/admin/css/fonts.css);
        html, body{
            width: 100%;
            height: 100%;
            margin: 0;
            padding: 0;
        }
        body{
            display: -webkit-box;
            display: -ms-flexbox;
            display: flex;
            -webkit-box-align: center;
            -ms-flex-align: center;
            align-items: center;
            -ms-flex-item-align: center;
            align-self: center;
            -ms-flex-line-pack: center;
            align-content: center;
            -webkit-box-pack: center;
            -ms-flex-pack: center;
            justify-content: center;
            background: #CFD8DC;
            background: -webkit-radial-gradient(circle, #455A64, #fff 0%, #264857 100%);
            background: -o-radial-gradient(circle, #455A64, #fff 0%, #264857 100%);
            background: -moz-radial-gradient(circle, #455A64, #fff 0%, #264857 100%);
            background: radial-gradient(circle, #455A64, #fff 0%, #264857 100%);
            color: #455A64;
            font-family: "PtSans", "Lucida Grande", "DejaVu Sans", "Bitstream Vera Sans", Verdana, Arial, sans-serif;
        }
        body > div {
            text-align: center;
        }
    </style>
</head>
<body>
    <div>
        <img src="/media/piscix_logo/custom-error500.png" alt="{% trans 'Server error (500)' %}" /><br>
        <p>{% trans "There's been an error. It's been reported to the site administrators via email and should be fixed shortly. Thanks for your patience." %}</p>
        <a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
    </div>
</body>
</html>
