@font-face {
    font-family: 'PtSans';
    src: url('../fonts/pt_sans-narrow-bold-webfont.woff') format('woff'), url('../fonts/pt_sans-narrow-bold-webfont.woff2') format('woff2');
    font-weight: 700;
    font-style: normal;
}
@font-face {
    font-family: 'PtSans';
    src: url('../fonts/pt_sans-narrow-regular-webfont.woff') format('woff'), url('../fonts/pt_sans-narrow-regular-webfont.woff2') format('woff2');
    font-weight: 400;
    font-style: normal;
}
@font-face {
    font-family: 'PtSans';
    src: url('../fonts/pt_sans-narrow-regular-webfont.woff') format('woff'), url('../fonts/pt_sans-narrow-regular-webfont.woff2') format('woff2');
    font-weight: 300;
    font-style: normal;
}
@font-face {
    font-family: 'Material Icons';
    font-style: normal;
    font-weight: 400;
    src: url('../fonts/MaterialIcons/MaterialIcons-Regular.eot');
    /* For IE6-8 */
    src: local('Material Icons'), local('MaterialIcons-Regular'), url('../fonts/MaterialIcons/MaterialIcons-Regular.woff2') format('woff2'), url('../fonts/MaterialIcons/MaterialIcons-Regular.woff') format('woff'), url('../fonts/MaterialIcons/MaterialIcons-Regular.ttf') format('truetype');
}
.micon {
    font-family: 'Material Icons';
    font-weight: normal;
    font-style: normal;
    font-size: 24px;
    /* Preferred icon size */
    display: inline-block;
    line-height: 1;
    text-transform: none;
    letter-spacing: normal;
    word-wrap: normal;
    white-space: nowrap;
    direction: ltr;
    /* Support for all WebKit browsers. */
    -webkit-font-smoothing: antialiased;
    /* Support for Safari and Chrome. */
    text-rendering: optimizeLegibility;
    /* Support for Firefox. */
    -moz-osx-font-smoothing: grayscale;
    /* Support for IE. */
    font-feature-settings: 'liga';
    vertical-align: middle;
}
