html {
    margin: 0;
    padding: 0;
    width: 100%;
    height: 100%;
    background: red;
    background: #263238;
    background: -webkit-radial-gradient(circle, #263238, #fff 0%, #263238 100%);
    background: -o-radial-gradient(circle, #263238, #fff 0%, #263238 100%);
    background: -moz-radial-gradient(circle, #263238, #fff 0%, #263238 100%);
    background: radial-gradient(circle, #263238, #fff 0%, #263238 100%);
    color: #004F65;
    font-family: "PtSans", "Lucida Grande", "DejaVu Sans", "Bitstream Vera Sans", Verdana, Arial, sans-serif;
}
.micon {
    font-size: 75px;
    color: #004F65;
    transition: color .7s;
}
a {
    display: block;
    font-weight: bold;
    text-decoration: none;
    font-size: 30px;
    padding: 7px 28px 7px 7px;
    color: #004F65;
    border-radius: 3px;
    transition: all .7s;
}
a:hover {
    color: #fff;
    padding: 7px 7px 7px 28px;
    background: #263238;
}
a:hover .micon {
    color: #fff;
}
body {
    margin: 0;
    padding: 0;
    width: 100%;
    height: 100%;
    font-family: "PtSans", "Lucida Grande", "DejaVu Sans", "Bitstream Vera Sans", Verdana, Arial, sans-serif;
}
table {
    width: 100%;
    height: 100%;
}
table td:first-child {
    /*border-right: 1px solid #000;*/
}
table td > ul {
    list-style: none;
    width: 80%;
}
table td > ul > li {
    padding: 7px 0;
}
.logo {
    width: 100%;
    height: 100%;
    display: flex;
    align-items: center;
    align-content: center;
    align-self: center;
    justify-content: center;
}
.logo > div {
    background-size: contain;
    background-repeat: no-repeat;
    vertical-align: bottom;
    background-position: center;
    vertical-align: text-bottom;
}
.logo > div > h2 {
    position: relative;
    bottom: -31rem;
    text-align: center;
}
